@@ -16,7 +16,7 @@
 #' @param objects A list of [splines::bs()] objects
 #'  created once the step has been trained.
 #' @param deg_free The degrees of freedom.
-#' @param degree The degree of the piecewise polynomial.
+#' @param degree Degree of polynomial spline (integer).
 #' @param options A list of options for [splines::bs()]
 #'  which should not include `x`, `degree`, or `df`.
 #' @return An updated version of `recipe` with the new step
@@ -63,6 +63,7 @@ step_bs <-
            options = list(),
            skip = FALSE,
            id = rand_id("bs")) {
+
     add_step(
       recipe,
       step_bs_new(
@@ -95,7 +96,6 @@ step_bs_new <-
     )
   }
 
-#' @importFrom splines bs
 bs_wrapper <- function(x, args) {
   if (!("Boundary.knots" %in% names(args)))
     args$Boundary.knots <- range(x)
@@ -135,8 +135,6 @@ prep.step_bs <- function(x, training, info = NULL, ...) {
   )
 }
 
-#' @importFrom tibble as_tibble is_tibble
-#' @importFrom stats predict
 #' @export
 bake.step_bs <- function(object, new_data, ...) {
   ## pre-allocate a matrix for the basis functions.
@@ -183,3 +181,20 @@ tidy.step_bs <- function(x, ...) {
   res$id <- x$id
   as_tibble(res)
 }
+
+# ------------------------------------------------------------------------------
+
+#' @rdname tunable.step
+#' @export
+tunable.step_bs <- function(x, ...) {
+  tibble::tibble(
+    name = c("deg_free", "degree"),
+    call_info = list(
+      list(pkg = "dials", fun = "deg_free", range = c(3, 15)),
+      list(pkg = "dials", fun = "degree_int", range = c(1, 2))
+    ),
+    source = "recipe",
+    component = "step_bs",
+    component_id = x$id
+  )
+}
