@@ -20,9 +20,6 @@
 #'  used.
 #' @param neighbors The number of neighbors.
 #' @param options A list of options to [dimRed::Isomap()].
-#' @param num The number of isomap dimensions (this will be deprecated
-#'  in factor of  `num_terms` in version 0.1.5). `num_terms` will
-#'  override this option.
 #' @param res The [dimRed::Isomap()] object is stored
 #'  here once this preprocessing step has be trained by
 #'  [prep.recipe()].
@@ -81,11 +78,8 @@
 #'
 #' im_trans <- rec %>%
 #'   step_YeoJohnson(all_predictors()) %>%
-#'   step_center(all_predictors()) %>%
-#'   step_scale(all_predictors()) %>%
-#'   step_isomap(all_predictors(),
-#'               neighbors = 100,
-#'               num_terms = 2)
+#'   step_normalize(all_predictors()) %>%
+#'   step_isomap(all_predictors(), neighbors = 100, num_terms = 2)
 #'
 #' if (require(dimRed) & require(RSpectra)) {
 #'   im_estimates <- prep(im_trans, training = biomass_tr)
@@ -96,8 +90,8 @@
 #'   plot(im_te$Isomap1, im_te$Isomap2,
 #'        xlim = rng, ylim = rng)
 #'
-#'   tidy(im_trans, number = 4)
-#'   tidy(im_estimates, number = 4)
+#'   tidy(im_trans, number = 3)
+#'   tidy(im_estimates, number = 3)
 #' }
 #' }
 #' @seealso [step_pca()] [step_kpca()]
@@ -113,15 +107,12 @@ step_isomap <-
            neighbors = 50,
            options = list(.mute = c("message", "output")),
            res = NULL,
-           num = NULL,
            prefix = "Isomap",
            skip = FALSE,
            id = rand_id("isomap")) {
 
     recipes_pkg_check(c("dimRed", "RSpectra", "igraph", "RANN"))
-    if (!is.null(num))
-      message("The argument `num` is deprecated in factor of `num_terms`. ",
-              "`num` will be removed in next version.", call. = FALSE)
+
     add_step(
       recipe,
       step_isomap_new(
@@ -132,7 +123,6 @@ step_isomap <-
         neighbors = neighbors,
         options = options,
         res = res,
-        num = num,
         prefix = prefix,
         skip = skip,
         id = id
@@ -141,7 +131,7 @@ step_isomap <-
   }
 
 step_isomap_new <-
-  function(terms, role, trained, num_terms, neighbors, options, res, num,
+  function(terms, role, trained, num_terms, neighbors, options, res,
            prefix, skip, id) {
     step(
       subclass = "isomap",
@@ -152,7 +142,6 @@ step_isomap_new <-
       neighbors = neighbors,
       options = options,
       res = res,
-      num = num,
       prefix = prefix,
       skip = skip,
       id = id
@@ -168,16 +157,22 @@ prep.step_isomap <- function(x, training, info = NULL, ...) {
     x$num_terms <- min(x$num_terms, ncol(training))
     x$neighbors <- min(x$neighbors, nrow(training))
 
-    imap <-
-      dimRed::embed(
-        dimRed::dimRedData(as.data.frame(training[, col_names, drop = FALSE])),
-        "Isomap",
-        knn = x$neighbors,
-        ndim = x$num_terms,
-        .mute = x$options$.mute
-      )
+    iso_map <-
+      try(
+        dimRed::embed(
+          dimRed::dimRedData(as.data.frame(training[, col_names, drop = FALSE])),
+          "Isomap",
+          knn = x$neighbors,
+          ndim = x$num_terms,
+          .mute = x$options$.mute
+        ),
+        silent = TRUE)
+    if (inherits(iso_map, "try-error")) {
+      stop("`step_isomap` failed with error:\n", as.character(iso_map), call. = FALSE)
+    }
+
   } else {
-    imap <- list(x_vars = col_names)
+    iso_map <- list(x_vars = col_names)
   }
 
   step_isomap_new(
@@ -187,8 +182,7 @@ prep.step_isomap <- function(x, training, info = NULL, ...) {
     num_terms = x$num_terms,
     neighbors = x$neighbors,
     options = x$options,
-    res = imap,
-    num = x$num_terms,
+    res = iso_map,
     prefix = x$prefix,
     skip = x$skip,
     id = x$id
@@ -243,3 +237,20 @@ tidy.step_isomap <- function(x, ...) {
   res$id <- x$id
   res
 }
+
+
+
+#' @rdname tunable.step
+#' @export
+tunable.step_isomap <- function(x, ...) {
+  tibble::tibble(
+    name = c("num_terms", "neighbors"),
+    call_info = list(
+      list(pkg = "dials", fun = "num_terms", range = c(1, 4)),
+      list(pkg = "dials", fun = "neighbors", range = c(1, 15))
+    ),
+    source = "recipe",
+    component = "step_isomap",
+    component_id = x$id
+  )
+}
