@@ -26,9 +26,6 @@
 #' @param res An S4 [kernlab::kpca()] object is stored
 #'  here once this preprocessing step has be trained by
 #'  [prep.recipe()].
-#' @param num The number of components to retain (this will be
-#'  deprecated in factor of `num_comp` in version 0.1.5). `num_comp`
-#'  will override this option.
 #' @param prefix A character string that will be the prefix to the
 #'  resulting new variables. See notes below.
 #' @return An updated version of `recipe` with the new step
@@ -94,8 +91,7 @@
 #'
 #' kpca_trans <- rec %>%
 #'   step_YeoJohnson(all_predictors()) %>%
-#'   step_center(all_predictors()) %>%
-#'   step_scale(all_predictors()) %>%
+#'   step_normalize(all_predictors()) %>%
 #'   step_kpca(all_predictors())
 #'
 #' if (require(dimRed) & require(kernlab)) {
@@ -107,8 +103,8 @@
 #'   plot(kpca_te$kPC1, kpca_te$kPC2,
 #'        xlim = rng, ylim = rng)
 #'
-#'   tidy(kpca_trans, number = 4)
-#'   tidy(kpca_estimates, number = 4)
+#'   tidy(kpca_trans, number = 3)
+#'   tidy(kpca_estimates, number = 3)
 #' }
 #' @seealso [step_pca()] [step_ica()]
 #'   [step_isomap()] [recipe()] [prep.recipe()]
@@ -123,15 +119,17 @@ step_kpca <-
            res = NULL,
            options = list(kernel = "rbfdot",
                           kpar = list(sigma = 0.2)),
-           num = NULL,
            prefix = "kPC",
            skip = FALSE,
            id = rand_id("kpca")) {
 
     recipes_pkg_check(c("dimRed", "kernlab"))
-    if (!is.null(num))
-      message("The argument `num` is deprecated in factor of `num_comp`. ",
-              "`num` will be removed in next version.", call. = FALSE)
+    message(
+      paste(
+        "`step_kpca()` is deprecated in favor of either `step_kpca_rbf()`",
+        "or `step_kpca_poly()`. It will be removed in future versions."
+      )
+    )
 
     add_step(
       recipe,
@@ -141,7 +139,6 @@ step_kpca <-
         trained = trained,
         num_comp = num_comp,
         res = res,
-        num = num,
         options = options,
         prefix = prefix,
         skip = skip,
@@ -151,7 +148,7 @@ step_kpca <-
 }
 
 step_kpca_new <-
-  function(terms, role, trained, num_comp, res, options, prefix, num, skip, id) {
+  function(terms, role, trained, num_comp, res, options, prefix, skip, id) {
     step(
       subclass = "kpca",
       terms = terms,
@@ -161,7 +158,6 @@ step_kpca_new <-
       res = res,
       options = options,
       prefix = prefix,
-      num = num,
       skip = skip,
       id = id
     )
@@ -174,10 +170,17 @@ prep.step_kpca <- function(x, training, info = NULL, ...) {
 
   if (x$num_comp > 0) {
     kprc <- dimRed::kPCA(stdpars = c(list(ndim = x$num_comp), x$options))
-    kprc <- kprc@fun(
-      dimRed::dimRedData(as.data.frame(training[, col_names, drop = FALSE])),
-      kprc@stdpars
-    )
+    kprc <-
+      try(
+        kprc@fun(
+          dimRed::dimRedData(as.data.frame(training[, col_names, drop = FALSE])),
+          kprc@stdpars
+        ),
+        silent = TRUE
+      )
+    if (inherits(kprc, "try-error")) {
+      stop("`step_kpca` failed with error:\n", as.character(kprc), call. = FALSE)
+    }
   } else {
     kprc <- list(x_vars = col_names)
   }
@@ -190,7 +193,6 @@ prep.step_kpca <- function(x, training, info = NULL, ...) {
     options = x$options,
     res = kprc,
     prefix = x$prefix,
-    num = x$num_comp,
     skip = x$skip,
     id = x$id
   )
@@ -221,7 +223,7 @@ print.step_kpca <- function(x, width = max(20, options()$width - 40), ...) {
     }
   } else {
     cat("Kernel PCA extraction with ", sep = "")
-    cat(format_selectors(x$terms, wdth = width))
+    cat(format_selectors(x$terms, width = width))
   }
   if (x$trained) cat(" [trained]\n") else cat("\n")
   invisible(x)
