@@ -2,7 +2,6 @@ filter_terms <- function(x, ...)
   UseMethod("filter_terms")
 
 ## Buckets variables into discrete, mutally exclusive types
-#' @importFrom tibble tibble
 get_types <- function(x) {
   var_types <-
     c(
@@ -41,7 +40,6 @@ get_types <- function(x) {
 is_formula <- function(x)
   isTRUE(inherits(x, "formula"))
 
-#' @importFrom rlang f_lhs
 get_lhs_vars <- function(formula, data) {
   if (!is_formula(formula))
     formula <- as.formula(formula)
@@ -51,13 +49,13 @@ get_lhs_vars <- function(formula, data) {
   get_rhs_vars(new_formula, data)
 }
 
-#' @importFrom rlang f_rhs
-#' @importFrom stats model.frame
 get_rhs_vars <- function(formula, data, no_lhs = FALSE) {
-  if (!is_formula(formula))
+  if (!is_formula(formula)) {
     formula <- as.formula(formula)
-  if(no_lhs)
+  }
+  if (no_lhs) {
     formula <- as.formula(paste("~", deparse(f_rhs(formula))))
+  }
 
   ## This will need a lot of work to account for cases with `.`
   ## or embedded functions like `Sepal.Length + poly(Sepal.Width)`.
@@ -75,36 +73,7 @@ get_rhs_vars <- function(formula, data, no_lhs = FALSE) {
 get_lhs_terms <- function(x) x
 get_rhs_terms <- function(x) x
 
-## ancillary step functions
 
-## then 9 is to keep space for "[trained]"
-format_ch_vec <-
-  function(x,
-           sep = ", ",
-           width = options()$width - 9) {
-    widths <- nchar(x)
-    sep_wd <- nchar(sep)
-    adj_wd <- widths + sep_wd
-    if (sum(adj_wd) >= width) {
-      keepers <- max(which(cumsum(adj_wd) < width)) - 1
-      if (length(keepers) == 0 || keepers < 1) {
-        x <- paste(length(x), "items")
-      } else {
-        x <- c(x[1:keepers], "...")
-      }
-    }
-    paste0(x, collapse = sep)
-  }
-
-format_selectors <- function(x, wdth = options()$width - 9, ...) {
-  ## convert to character without the leading ~
-  x_items <- lapply(x, function(x) {
-    as.character(get_expr(x))
-  })
-
-  x_items <- unlist(x_items)
-  format_ch_vec(x_items, width = wdth, sep = ", ")
-}
 
 terms.recipe <- function(x, ...)
   x$term_info
@@ -253,7 +222,6 @@ strings2factors <- function(x, info) {
 # as missing if _all_ values are missing. For if a list vector element is a
 # data frame with one missing value, that element of the list column will
 # be counted as complete.
-#' @importFrom purrr map_dfc
 n_complete_rows <- function(x) {
   list_cols <- purrr::map_lgl(x, is.list)
   list_cols <- names(list_cols)[list_cols]
@@ -294,7 +262,7 @@ train_info <- function(x) {
 ## and merges them. Special attention is paid to cases where the
 ## _type_ of data is changed for a common column in the data.
 
-#' @importFrom dplyr right_join mutate rename select
+
 merge_term_info <- function(.new, .old) {
   # Look for conflicts where the new variable type is different from
   # the original value
@@ -312,7 +280,6 @@ merge_term_info <- function(.new, .old) {
 #'
 #' @param ... Arguments pass in from a call to `step`
 #' @return If not empty, a list of quosures. If empty, an error is thrown.
-#' @importFrom rlang quos is_empty
 #' @export
 #' @keywords internal
 #' @rdname recipes-internal
@@ -325,11 +292,6 @@ ellipse_check <- function(...) {
   terms
 }
 
-#' @importFrom magrittr %>%
-#' @export
-magrittr::`%>%`
-
-
 #' Printing Workhorse Function
 #'
 #' This internal function is used for printing steps.
@@ -352,7 +314,7 @@ printer <- function(tr_obj = NULL,
   if (trained) {
     txt <- format_ch_vec(tr_obj, width = width)
   } else
-    txt <- format_selectors(untr_obj, wdth = width)
+    txt <- format_selectors(untr_obj, width = width)
   if (nchar(txt) == 0)
     txt <- "<none>"
   cat(txt)
@@ -479,14 +441,12 @@ is_trained <- function(x)
 #' @param x A list of selectors
 #' @return A character vector
 #' @export
-#' @importFrom purrr map_chr
 #' @keywords internal
 #' @rdname recipes-internal
 sel2char <- function(x) {
   map_chr(x, to_character)
 }
 
-#' @importFrom rlang is_quosure quo_text as_character
 to_character <- function(x) {
   if (rlang::is_quosure(x)) {
     res <- rlang::quo_text(x)
@@ -601,7 +561,37 @@ check_nominal_type <- function(x, lvl) {
 }
 
 # ------------------------------------------------------------------------------
+# From parsnip, keep synced
 
-#' @importFrom utils globalVariables
-utils::globalVariables(c("type", "new_type"))
+is_varying <- function(x) {
+  if (is.null(x)) {
+    res <- FALSE
+  } else {
+    res <- if (is_quosure(x))
+      isTRUE(all.equal(x[[-1]], quote(varying())))
+    else
+      isTRUE(all.equal(x, quote(varying())))
+  }
+  res
+}
+
+# from tune package
+is_tune <- function(x) {
+  if (is.call(x)) {
+    if (rlang::call_name(x) == "tune") {
+      return(TRUE)
+    } else {
+      return(FALSE)
+    }
+  } else {
+    return(FALSE)
+  }
+  FALSE
+}
+
+# ------------------------------------------------------------------------------
+
+tidyr_new_interface <- function() {
+  utils::packageVersion("tidyr") > "0.8.99"
+}
 
