@@ -18,7 +18,8 @@
 #'  `tidy` method, a tibble with columns `terms` which
 #'  is the columns that will be removed.
 #' @keywords datagen
-#' @concept preprocessing variable_filters
+#' @concept preprocessing
+#' @concept variable_filters
 #' @export
 #' @examples
 #' data(biomass)
@@ -99,7 +100,7 @@ print.step_rm <-
         cat("No variables were removed")
     } else {
       cat("Delete terms ", sep = "")
-      cat(format_selectors(x$terms, wdth = width))
+      cat(format_selectors(x$terms, width = width))
     }
     if (x$trained)
       cat(" [trained]\n")
