@@ -1,6 +1,9 @@
 library(testthat)
 library(recipes)
 
+context("Data framedness")
+
+
 ###################################################################
 
 data(okc)
@@ -23,15 +26,15 @@ rec <- recipe( ~ ., data = okc_tr) %>%
 ###################################################################
 
 test_that('correct types', {
-  bake_default <- bake(rec, newdata = okc_te, all_numeric())
+  bake_default <- bake(rec, new_data = okc_te, all_numeric())
   bake_df <-
     bake(rec,
-         newdata = okc_te,
+         new_data = okc_te,
          all_numeric(),
          composition = "data.frame")
   bake_df_1d <-
     bake(rec,
-         newdata = okc_te,
+         new_data = okc_te,
          age,
          composition = "data.frame")
   juice_default <- juice(rec, all_numeric())
