@@ -72,3 +72,18 @@ test_that('printing', {
   expect_output(prep(impute_rec, training = credit_tr, verbose = TRUE))
 })
 
+
+test_that('tunable', {
+  rec <-
+    recipe(~ ., data = iris) %>%
+    step_meanimpute(all_predictors())
+  rec_param <- tunable.step_meanimpute(rec$steps[[1]])
+  expect_equal(rec_param$name, c("trim"))
+  expect_true(all(rec_param$source == "recipe"))
+  expect_true(is.list(rec_param$call_info))
+  expect_equal(nrow(rec_param), 1)
+  expect_equal(
+    names(rec_param),
+    c('name', 'call_info', 'source', 'component', 'component_id')
+  )
+})
