@@ -95,13 +95,6 @@ test_that('Reduced rotation size', {
   expect_equal(pca_pred, pca_pred_exp)
 })
 
-test_that('deprecated arg', {
-  expect_message(
-    rec %>%
-      step_pca(carbon, hydrogen, oxygen, nitrogen, sulfur, num = 2)
-  )
-})
-
 test_that('printing', {
   pca_extract <- rec %>%
     step_pca(carbon, hydrogen, oxygen, nitrogen, sulfur)
@@ -124,3 +117,18 @@ test_that('No PCA comps', {
                 regexp = "No PCA components were extracted")
   expect_true(all(is.na(tidy(pca_extract_trained, 1)$value)))
 })
+
+test_that('tunable', {
+  rec <-
+    recipe(~ ., data = iris) %>%
+    step_pca(all_predictors())
+  rec_param <- tunable.step_pca(rec$steps[[1]])
+  expect_equal(rec_param$name, c("num_comp"))
+  expect_true(all(rec_param$source == "recipe"))
+  expect_true(is.list(rec_param$call_info))
+  expect_equal(nrow(rec_param), 1)
+  expect_equal(
+    names(rec_param),
+    c('name', 'call_info', 'source', 'component', 'component_id')
+  )
+})
